@@ -9,4 +9,4 @@ ADMIN_COMMAND_PERMISSION = 'admin'
          help='make the bot shutdown')
 async def cmd_shutdown(msg: Message, *args):
     await msg.reply('bot shutting down...')
-    get_bot().shutdown()
+    await get_bot().shutdown()
